# `rai`, RadiotherapyAI's non-clinical open source autocontouring library

This Open Source Unregulated Software is provided in the hope that it might be
useful but WITHOUT ANY WARRANTY. It is **not** intended for clinical use, and
is instead intended for research use only.

If you are looking for the Regulated Medical Device, `RAIContours`, that is
based upon the source code within this repository, when it has completed its
regulatory approval, it will be available for download directly from
<https://radiotherapy.ai/>. Prior to regulatory approval, you may be able to
utilise `RAIContours` under a clinical trial notification or equivalent. If you
are interested in undergoing a clinical trial with `RAIContours` please reach
out to <clinical-trials@radiotherapy.ai>.

## Goal

Create an AI Software as a Medical Device that saves lives built entirely from
open source software. Being a part of making it easier for researchers to
translate from "bench-top to bedside", helping anyone to build regulated tools
that go on to save more lives than any one of us alone could ever hope to
achieve.

## Installation

This open source research library is able to be installed by running:

```
pip install rai
```

## The regulatory documentation

All of the regulatory documentation is available under a creative commons
license and is built upon
[the amazing templates](https://openregulatory.com/templates/)
provided by [OpenRegulatory](https://openregulatory.com/).

The source code for the regulatory documentation is available within the
[docs directory](./docs). The online rendering of the documentation is viewable
at <https://docs.radiotherapy.ai>

The regulatory task is currently a work in progress. Right now I am just
learning the regulatory ropes while putting all of my warts up here for all to
see. There will be mistakes. If you find them please let me know. Also, if you
want to help out, please get in touch. My email address is
simon.biggs@radiotherapy.ai.
